==> flyway-core-7.15.0-sources.jar: org/flywaydb/core/internal/util/FlywayDbWebsiteLinks.java <==
/*
 * Copyright (C) Red Gate Software Ltd 2010-2021
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flywaydb.core.internal.util;

import org.flywaydb.core.api.MigrationVersion;
import org.flywaydb.core.internal.license.VersionPrinter;










public class FlywayDbWebsiteLinks {
    public static final String TRY_TEAMS_EDITION = "https://rd.gt/2VzHpkY";
    public static final String TRY_TEAMS_EDITION_DEFAULT_TRIAL = "https://rd.gt/3A4IWym";
    public static final String FILTER_INFO_OUTPUT = "https://rd.gt/3jqLqAn";
    public static final String USAGE_COMMANDLINE = "https://rd.gt/3Cc1xKC";
    public static final String STAYING_UP_TO_DATE = "https://rd.gt/3rXiSlV";
    public static final String CUSTOM_VALIDATE_RULES = "https://rd.gt/3AbJUZE";
    public static final String IGNORE_MIGRATION_PATTERNS = "https://rd.gt/37m4hXD";
    public static final String RESET_THE_BASELINE_MIGRATION = "https://rd.gt/3CdwkXD";
    public static final String ORACLE_SQL_PLUS = "https://rd.gt/3AdsFHj";
    public static final String LOCK_RETRY_COUNT = "https://rd.gt/3A57jfk";
    public static final String WINDOWS_AUTH = "https://rd.gt/3ioP5iI";
    public static final String AZURE_ACTIVE_DIRECTORY = "https://rd.gt/2TYKavG";
    public static final String TRIAL_UPGRADE = "https://rd.gt/2WNixqj";
    public static final String KNOWN_PARSER_LIMITATIONS = "https://rd.gt/3ipi7Pm";
    public static final String BIG_QUERY_BETA = "https://rd.gt/3fut40f";
    public static final String CLOUD_SPANNER_BETA = "https://rd.gt/3yqM3jJ";
    public static final String TEAMS_FEATURES_FOR_BIG_QUERY = "https://rd.gt/3lNeuVJ";
    public static final String TEAMS_FEATURES_FOR_CLOUD_SPANNER = "https://rd.gt/3fzZdUa";
}

==> flyway-core-8.0.0-sources.jar: org/flywaydb/core/internal/util/FlywayDbWebsiteLinks.java <==
/*
 * Copyright (C) Red Gate Software Ltd 2010-2021
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flywaydb.core.internal.util;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.flywaydb.core.api.MigrationVersion;
import org.flywaydb.core.internal.license.VersionPrinter;










@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class FlywayDbWebsiteLinks {
    public static final String TRY_TEAMS_EDITION = "https://rd.gt/2VzHpkY";
    public static final String TRY_TEAMS_EDITION_DEFAULT_TRIAL = "https://rd.gt/3A4IWym";
    public static final String FILTER_INFO_OUTPUT = "https://rd.gt/3jqLqAn";
    public static final String USAGE_COMMANDLINE = "https://rd.gt/3Cc1xKC";
    public static final String STAYING_UP_TO_DATE = "https://rd.gt/3rXiSlV";
    public static final String CUSTOM_VALIDATE_RULES = "https://rd.gt/3AbJUZE";
    public static final String IGNORE_MIGRATION_PATTERNS = "https://rd.gt/37m4hXD";
    public static final String RESET_THE_BASELINE_MIGRATION = "https://rd.gt/3CdwkXD";
    public static final String ORACLE_SQL_PLUS = "https://rd.gt/3AYVsQY";
    public static final String LOCK_RETRY_COUNT = "https://rd.gt/3A57jfk";
    public static final String WINDOWS_AUTH = "https://rd.gt/39KICcS";
    public static final String AZURE_ACTIVE_DIRECTORY = "https://rd.gt/3unaRb8";
    public static final String TRIAL_UPGRADE = "https://rd.gt/2WNixqj";
    public static final String KNOWN_PARSER_LIMITATIONS = "https://rd.gt/3ipi7Pm";
    public static final String BIG_QUERY_BETA = "https://rd.gt/3fut40f";
    public static final String CLOUD_SPANNER_BETA = "https://rd.gt/3yqM3jJ";
    public static final String TEAMS_FEATURES_FOR_BIG_QUERY = "https://rd.gt/3CWAuTb";
    public static final String TEAMS_FEATURES_FOR_CLOUD_SPANNER = "https://rd.gt/2ZvELhV";
}
